@@ -11,8 +11,8 @@ mod wire_msg_header;
 
 pub use self::wire_msg::WireMsg;
 use super::{
-    data::DataMsg, node::NodeMsg, section_info::SectionInfoMsg, BlsShareSigned, DataAuthority,
-    DstLocation, MessageId, NodeSigned, SectionSigned,
+    data::DataMsg, node::NodeMsg, section_info::SectionInfoMsg, Authority, BlsShareSigned,
+    DataSigned, DstLocation, MessageId, NodeSigned, SectionSigned,
 };
 
 /// Type of message.
@@ -35,7 +35,7 @@ pub enum MessageType {
         /// Message ID
         msg_id: MessageId,
         /// Requester's authority over this message
-        data_auth: DataAuthority,
+        data_auth: Authority<DataSigned>,
         /// Message destination location
         dst_location: DstLocation,
         /// the message
@@ -59,9 +59,9 @@ pub enum MessageType {
 #[derive(PartialEq, Debug, Clone)]
 pub enum NodeMsgAuthority {
     /// Authority of a single peer.
-    Node(NodeSigned),
+    Node(Authority<NodeSigned>),
     /// Authority of a single peer that uses it's BLS Keyshare to sign the message.
-    BlsShare(BlsShareSigned),
+    BlsShare(Authority<BlsShareSigned>),
     /// Authority of a whole section.
-    Section(SectionSigned),
+    Section(Authority<SectionSigned>),
 }
