@@ -21,7 +21,7 @@ mod sync;
 use super::Core;
 use crate::messaging::{
     node::{NodeMsg, Proposal},
-    BlsShareSigned, DstLocation, MessageId, MessageType, NodeMsgAuthority, SectionSigned, WireMsg,
+    Authority, DstLocation, MessageId, MessageType, NodeMsgAuthority, SectionSigned, WireMsg,
 };
 use crate::routing::{
     core::AggregatorError,
@@ -60,15 +60,6 @@ impl Core {
             }
         }
 
-        // Now check the signature of the msg authority is valid
-        if let Err(err) = wire_msg.check_signature() {
-            error!(
-                "Discarding message received ({:?}) due to invalid signature: {:?}",
-                msg_id, err
-            );
-            return Ok(vec![]);
-        }
-
         // We can now deserialize the payload of the incoming message
         let payload = wire_msg.payload.clone();
         let message_type = match wire_msg.into_message() {
@@ -159,7 +150,7 @@ impl Core {
             );
 
             // We assume to be aggregated if it contains a BLS Share sig as authority.
-            match self.aggregate_message_and_stop(&msg_id, &mut msg_authority, payload) {
+            match self.aggregate_message_and_stop(&mut msg_authority, payload) {
                 Ok(false) => {
                     commands.extend(
                         self.handle_verified_node_message(
@@ -212,7 +203,7 @@ impl Core {
                 // TODO: preserve the source bytes so we don't need to serialize again here, or else
                 // verify earlier.
                 let payload = WireMsg::serialize_msg_payload(&msg)?;
-                let data_auth = data_signed.verify(&payload)?;
+                let data_auth = Authority::verify(data_signed, &payload)?;
 
                 self.handle_client_msg_received(msg_id, msg, user, data_auth)
                     .await
@@ -415,38 +406,6 @@ impl Core {
                 .await;
                 Ok(vec![])
             }
-            NodeMsg::NodeCmdError {
-                error,
-                correlation_id,
-            } => {
-                self.send_event(Event::MessageReceived {
-                    msg_id,
-                    src: msg_authority.src_location(),
-                    dst: dst_location,
-                    msg: Box::new(MessageReceived::NodeCmdError {
-                        error,
-                        correlation_id,
-                    }),
-                })
-                .await;
-                Ok(vec![])
-            }
-            NodeMsg::NodeEvent {
-                event,
-                correlation_id,
-            } => {
-                self.send_event(Event::MessageReceived {
-                    msg_id,
-                    src: msg_authority.src_location(),
-                    dst: dst_location,
-                    msg: Box::new(MessageReceived::NodeEvent {
-                        event,
-                        correlation_id,
-                    }),
-                })
-                .await;
-                Ok(vec![])
-            }
             NodeMsg::NodeQuery(node_query) => {
                 self.send_event(Event::MessageReceived {
                     msg_id,
@@ -497,53 +456,27 @@ impl Core {
     // current message shall not be processed any further.
     fn aggregate_message_and_stop(
         &mut self,
-        msg_id: &MessageId,
         msg_authority: &mut NodeMsgAuthority,
         payload: Bytes,
     ) -> Result<bool> {
-        let (section_pk, src_name, sig_share) =
-            if let NodeMsgAuthority::BlsShare(BlsShareSigned {
-                section_pk,
-                src_name,
-                sig_share,
-            }) = msg_authority
-            {
-                (section_pk, src_name, sig_share)
-            } else {
-                // not a msg to aggregate signatures with,
-                // return wihout modifying msg_authority
-                return Ok(false);
-            };
-
-        match self.message_aggregator.add(&payload, sig_share.clone()) {
-            Ok(sig) => {
-                if sig_share.public_key_set.public_key() != sig.public_key {
-                    error!(
-                        "Signed public key doesn't match signed share public key in msg with id: {}",
-                        msg_id
-                    );
-                    return Err(Error::InvalidMessage);
-                }
-
-                if &sig.public_key != section_pk {
-                    error!(
-                        "Signed public key doesn't match the section PK in msg with id {}: {:?}",
-                        msg_id, section_pk
-                    );
-                    return Err(Error::InvalidMessage);
-                }
-
-                *msg_authority = NodeMsgAuthority::Section(SectionSigned {
-                    section_pk: *section_pk,
-                    src_name: *src_name,
-                    sig,
-                });
+        let bls_share_auth = if let NodeMsgAuthority::BlsShare(bls_share_auth) = msg_authority {
+            bls_share_auth
+        } else {
+            return Ok(false);
+        };
 
+        match SectionSigned::try_authorize(
+            &mut self.message_aggregator,
+            bls_share_auth.clone().into_inner(),
+            &payload,
+        ) {
+            Ok(section_auth) => {
+                *msg_authority = NodeMsgAuthority::Section(section_auth);
                 Ok(false)
             }
             Err(AggregatorError::NotEnoughShares) => Ok(true),
             Err(err) => {
-                error!("Error accumulating message at dst: {:?}", err);
+                error!("Error accumulating message at dst: {}", err);
                 Err(Error::InvalidSignatureShare)
             }
         }
